summaryrefslogtreecommitdiff
path: root/lib/gnutls_global.c
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2002-06-20 07:22:55 +0000
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2002-06-20 07:22:55 +0000
commit15ce639e5a18ebe40ffae904158cec6635deb084 (patch)
treeaf70fc75e7cd060e2fa0e3512497ed6c418e4ee6 /lib/gnutls_global.c
parentad7a5180e6c0066673e1f8b5fb8621b610cdca2d (diff)
downloadgnutls-15ce639e5a18ebe40ffae904158cec6635deb084.tar.gz
*** empty log message ***
Diffstat (limited to 'lib/gnutls_global.c')
-rw-r--r--lib/gnutls_global.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/gnutls_global.c b/lib/gnutls_global.c
index c4034840d7..77bbf28023 100644
--- a/lib/gnutls_global.c
+++ b/lib/gnutls_global.c
@@ -79,7 +79,7 @@ extern void* (*gnutls_calloc)(size_t, size_t);
int _gnutls_is_secure_mem_null( const void*);
/**
* gnutls_global_set_mem_function - This function sets the memory allocation functions
* @alloc_func: it's the default memory allocation function. Like malloc().
* @secure_alloc_func: This is the memory allocation function that will be used for sensitive data.
* @is_secure_func: a function that returns 0 if the memory given is not secure. May be NULL.
@@ -95,7 +95,7 @@ int _gnutls_is_secure_mem_null( const void*);
* This function must be called before gnutls_global_init() is called.
*
**/
-void gnutls_global_set_mem_function(
+void gnutls_global_set_mem_functions(
void *(*gnutls_alloc_func)(size_t), void* (*gnutls_secure_alloc_func)(size_t),
int (*gnutls_is_secure_func)(const void*), void *(*gnutls_realloc_func)(void *, size_t),
void (*gnutls_free_func)(void*))
@@ -79,7 +79,7 @@ extern void* (*gnutls_calloc)(size_t, size_t);
int _gnutls_is_secure_mem_null( const void*);
/**
- * gnutls_global_set_mem_function - This function sets the memory allocation functions
+ * gnutls_global_set_mem_functions - This function sets the memory allocation functions
* @alloc_func: it's the default memory allocation function. Like malloc().
* @secure_alloc_func: This is the memory allocation function that will be used for sensitive data.